@@ -1,5 +1,7 @@
 extern void printmask(char *name, nodemask_t *mask);
+extern void printcpumask(char *name, unsigned long *mask, int len);
 extern nodemask_t nodemask(char *s);
+extern unsigned long *cpumask(char *s, int *ncpus);
 extern int read_sysctl(char *name);
 extern void complain(char *fmt, ...);
 extern void nerror(char *fmt, ...);
@@ -14,3 +16,5 @@ extern char *policy_name(int policy);
 
 #define err(x) perror("numactl: " x),exit(1)
 #define array_len(x) (sizeof(x)/sizeof(*(x)))
+
+#define round_up(x,y) (((x) + (y) - 1) & ~((y)-1))
